"""
Binance.US API
https://docs.binance.us/?python#request-for-quote
"""

import hashlib
import hmac
import urllib.parse

import requests

api_url = "https://api.binance.us"
account_path = "/api/v3/account"
price_path='/api/v3/ticker/price'
quote_path = "/sapi/v1/otc/quotes"
place_order_path = "/sapi/v1/otc/orders"
order_path = "/sapi/v1/otc/orders"


# get binanceus signature
def get_binanceus_signature(data, secret):
    postdata = urllib.parse.urlencode(data)
    message = postdata.encode()
    byte_key = bytes(secret, 'UTF-8')
    mac = hmac.new(byte_key, message, hashlib.sha256).hexdigest()
    return mac


def binanceus_get(uri_path, data, api_key, api_sec):
    headers = {}
    headers['X-MBX-APIKEY'] = api_key
    signature = get_binanceus_signature(data, api_sec)
    params={
        **data,
        "signature": signature,
    }
    resp = requests.get((api_url + uri_path), params=params, headers=headers)
    return resp.json()


# Attaches auth headers and returns results of a POST request
def binanceus_post(uri_path, data, api_key, api_sec):
    headers = {}
    headers['X-MBX-APIKEY'] = api_key
    signature = get_binanceus_signature(data, api_sec)
    payload = {
        **data,
        "signature": signature,
    }
    resp = requests.post((api_url + uri_path), headers=headers, data=payload)
    return resp.json()



# pylint: skip-file
# pylint 忽略文件
from setuptools import setup, find_packages


def long_description():
    with open("README.md", "r") as fh:
        long_desc = fh.read()
        return long_desc


def requirements():
    with open("requirements.txt", "r") as fh:
        reqs = [line.strip() for line in fh]
        return reqs


setup(
    name='binance-us-client',
    version='0.0.1',  # 版本号
    description='tool pkg.',  # 包的介绍
    author='yromeMfOtuO',  # 作者 就是我啦～
    author_email='weihao.lv@outlook.com',  # 你的邮箱
    url='https://github.com/yromeMfOtuO/binance-us-client',  # 项目地址，一般的填git地址 也可以是任意可用的url 不过我喜欢使用 git
    packages=find_packages(),  # Python导入包的列表，我们使用find_packages() 来自动收集
    long_description=long_description(),  # 项目的描述 一般是 string 上文中定义了它
    long_description_content_type="text/markdown",  # 描述文档 README 的格式 一般我喜欢MD. 也可以是你喜欢的其他格式 支不支持我就不知道了～ 估计HTML 是支持的
    license="GPLv3",  # 开源协议
    # 这 需要去官网查，在下边提供了许可证连接 或者 你可以直接把我的粘贴走
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent"
    ],

    python_requires='>=3.6',  # Python 的版本约束
    # 其他依赖的约束
    install_requires=requirements()
)



from decimal import Decimal

import requests

from base_api import api_url, price_path


def get_symbol_price(symbol: str) -> Decimal:
    resp = requests.get(f'{api_url}{price_path}?symbol={symbol}')
    return Decimal(resp.json()['price'])


def get_coin_price(coin: str) -> Decimal:
    """
    USDT USD 价格为 1
    :param coin:
    :return:
    """
    if coin == 'USDT' or coin == 'USD':
        return Decimal(1)
    return get_symbol_price(f'{coin}USDT')


def batch_get_symbol_price(symbols: list[str]) -> dict:
    """
    :param symbols: symbol list
    :return: symbol -> price dict
    """
    return dict(zip(symbols, [get_symbol_price(symbol) for symbol in symbols]))


def batch_get_coin_price(coins: list[str]) -> dict:
    """
    :param coins: coin list
    :return: coin -> pice dict
    """
    return dict(zip(coins, [get_coin_price(coin) for coin in coins]))


if __name__ == '__main__':
    print(get_symbol_price('BTCUSDT'))
    print(get_coin_price('BTC'))
    print(batch_get_symbol_price(['BTCUSDT', 'ETHUSDT']))
    print(batch_get_coin_price(['BTC', 'ETH']))
